---------------------------------------------------------------------
-- Activity generation for SalesDBInts
---------------------------------------------------------------------

:SETVAR RowsToInsert 10000
go

set nocount on
go

USE SalesDBInts
go

DECLARE @StartTime	datetime2(7),
		@Counter	int

SELECT	@Counter = 0, 
		@StartTime = SYSDATETIME()

WHILE @Counter < $(RowsToInsert)
BEGIN
	IF OBJECTPROPERTY(object_id('Sales'), 'IsUserTable') = 1
		BEGIN
			INSERT Sales
				SELECT
					(SELECT EmployeeID 
						FROM Employees 
						WHERE ISNULL(NULLIF((datepart(ms, (getdate()))) %24, 0), 1) = EmployeeID),
					(SELECT CustomerID 
						FROM Customers 
						WHERE ISNULL(NULLIF((datepart(ms, (getdate()))) *10000 %19760, 0), 1) = CustomerID),
					(SELECT ProductID 
						FROM Products 
						WHERE ISNULL(NULLIF((datepart(ms, (getdate()))) %505, 0), 1) = ProductID),
					ISNULL(NULLIF((datepart(ms, getdate())), 0), 1)

			--SELECT @@IDENTITY AS 'SalesID Added'
		END
	ELSE
		BEGIN
			RAISERROR('The Sales object does not exist.', 16, 1)
		END
	SELECT @Counter = @Counter + 1
END

SELECT RowsInserted = @Counter,
	   TimeForInsert = DATEDIFF(ms, @StartTime, SYSDATETIME()) 
go

---------------------------------------------------------------------
-- Activity generation for SalesDBGUIDs
---------------------------------------------------------------------

USE SalesDBGUIDs
go

DECLARE @StartTime	datetime2(7),
		@Counter	int

DECLARE @InsertedSales table 
	(SalesGUID uniqueidentifier)

SELECT	@Counter = 0, 
		@StartTime = SYSDATETIME()

WHILE @Counter < $(RowsToInsert)
BEGIN
	IF OBJECTPROPERTY(object_id('Sales'), 'IsUserTable') = 1
		BEGIN
			INSERT Sales (SalesPersonGUID, CustomerGUID, ProductGUID, Quantity)
			--OUTPUT INSERTED.SalesGUID INTO @InsertedSales 
				SELECT
					(SELECT EmployeeGUID 
						FROM Employees 
						WHERE ISNULL(NULLIF((datepart(ms, (getdate()))) %24, 0), 1) = EmployeeID),
					(SELECT CustomerGUID 
						FROM Customers 
						WHERE ISNULL(NULLIF((datepart(ms, (getdate()))) *10000 %19760, 0), 1) = CustomerID),
					(SELECT ProductGUID 
						FROM Products 
						WHERE ISNULL(NULLIF((datepart(ms, (getdate()))) %505, 0), 1) = ProductID),
					ISNULL(NULLIF((datepart(ms, getdate())), 0), 1)

			--SELECT SalesGUID AS 'SalesGUID Added' FROM @InsertedSales
		END
	ELSE
		BEGIN
			RAISERROR('The Sales object does not exist.', 16, 1)
		END
	SELECT @Counter = @Counter + 1
END

SELECT RowsInserted = @Counter,
	   TimeForInsert = DATEDIFF(ms, @StartTime, SYSDATETIME()) 
go


---------------------------------------------------------------------
-- Activity generation for SalesDBSeqGUIDs
---------------------------------------------------------------------

USE SalesDBSeqGUIDs
go

DECLARE @StartTime	datetime2(7),
		@Counter	int

DECLARE @InsertedSales table 
	(SalesGUID uniqueidentifier)

SELECT	@Counter = 0, 
		@StartTime = SYSDATETIME()

WHILE @Counter < $(RowsToInsert)
BEGIN
	IF OBJECTPROPERTY(object_id('Sales'), 'IsUserTable') = 1
		BEGIN
			INSERT Sales (SalesPersonGUID, CustomerGUID, ProductGUID, Quantity)
			--OUTPUT INSERTED.SalesGUID INTO @InsertedSales 
				SELECT
					(SELECT EmployeeGUID 
						FROM Employees 
						WHERE ISNULL(NULLIF((datepart(ms, (getdate()))) %24, 0), 1) = EmployeeID),
					(SELECT CustomerGUID 
						FROM Customers 
						WHERE ISNULL(NULLIF((datepart(ms, (getdate()))) *10000 %19760, 0), 1) = CustomerID),
					(SELECT ProductGUID 
						FROM Products 
						WHERE ISNULL(NULLIF((datepart(ms, (getdate()))) %505, 0), 1) = ProductID),
					ISNULL(NULLIF((datepart(ms, getdate())), 0), 1)

			--SELECT SalesGUID AS 'SalesGUID Added' FROM @InsertedSales
		END
	ELSE
		BEGIN
			RAISERROR('The Sales object does not exist.', 16, 1)
		END
	SELECT @Counter = @Counter + 1
END

SELECT RowsInserted = @Counter,
	   TimeForInsert = DATEDIFF(ms, @StartTime, SYSDATETIME()) 
go

SELECT count(*) FROM SalesDBInts.dbo.Sales
SELECT count(*) FROM SalesDBGUIDs.dbo.Sales
SELECT count(*) FROM SalesDBSeqGUIDs.dbo.Sales
go

USE SalesDBInts
go

SELECT object_name(ps.object_id) AS TableName
	   , si.name AS IndexName
	   , ps.index_level AS IndexLevel
	   , ps.record_count AS RecordCount
	   , ps.page_count AS Pages
	   , ps.avg_fragmentation_in_percent
	   , ps.avg_page_space_used_in_percent
FROM sys.dm_db_index_physical_stats
	(db_id('SalesDBInts')
	, object_id('SalesDBInts.dbo.Sales')
	, null
	, null
	, 'detailed') AS ps
	JOIN SalesDBInts.sys.indexes AS si
		ON ps.object_id = si.object_id AND ps.index_id = si.index_id 
WHERE ps.index_level = 0
ORDER BY TableName, ps.index_id, ps.index_level
go

USE SalesDBGUIDs
go

SELECT object_name(ps.object_id) AS TableName
	   , si.name AS IndexName
	   , ps.index_level AS IndexLevel
	   , ps.record_count AS RecordCount
	   , ps.page_count AS Pages
	   , ps.avg_fragmentation_in_percent
	   , ps.avg_page_space_used_in_percent
FROM sys.dm_db_index_physical_stats
	(db_id('SalesDBGUIDs')
	, object_id('SalesDBGUIDs.dbo.Sales')
	, null
	, null
	, 'detailed') AS ps
	JOIN SalesDBGUIDs.sys.indexes AS si
		ON ps.object_id = si.object_id AND ps.index_id = si.index_id 
WHERE ps.index_level = 0
ORDER BY TableName, ps.index_id, ps.index_level
go

USE SalesDBSeqGUIDs
go
SELECT object_name(ps.object_id) AS TableName
	   , si.name AS IndexName
	   , ps.index_level AS IndexLevel
	   , ps.record_count AS RecordCount
	   , ps.page_count AS Pages
	   , ps.avg_fragmentation_in_percent
	   , ps.avg_page_space_used_in_percent
FROM sys.dm_db_index_physical_stats
	(db_id('SalesDBSeqGUIDs')
	, object_id('SalesDBSeqGUIDs.dbo.Sales')
	, null
	, null
	, 'detailed') AS ps
	JOIN SalesDBSeqGUIDs.sys.indexes AS si
		ON ps.object_id = si.object_id AND ps.index_id = si.index_id 
WHERE ps.index_level = 0
ORDER BY TableName, ps.index_id, ps.index_level
go