create table RandomGUIDs
(
	RowID	int					identity(1,1),
	GUIDID	uniqueidentifier	default newid(),
	InsWhen	datetime2			default sysdatetime()
)
go
create unique clustered index IX_RandomGUIDs on RandomGUIDs (GUIDID)
go
create table SequentialGUIDs
(
	RowID	int					identity(1,1),
	GUIDID	uniqueidentifier	default newsequentialid(),
	InsWhen	datetime2			default sysdatetime()
)
go
create unique clustered index IX_SequentialGUIDs on SequentialGUIDs (GUIDID)
go

set nocount on
go
insert RandomGUIDs default values
insert SequentialGUIDs default values
go 20000

select COUNT(*) from RandomGUIDs
select COUNT(*) from SequentialGUIDs
go

select * from sys.dm_db_index_physical_stats(DB_ID(), object_id('RandomGUIDs'), 1, null, 'detailed')
select * from sys.dm_db_index_physical_stats(DB_ID(), object_id('SequentialGUIDs'), 1, null, 'detailed')

SELECT convert(varbinary(4), GUIDID)
	, convert(varbinary(16), GUIDID)
	, GUIDID 
FROM SequentialGUIDs ORDER BY 1

SELECT l.RowID AS LowerRowID
	, h.RowID AS HigherRowID
	, convert(int, convert(varbinary(4), h.GUIDID)) - convert(int, convert(varbinary(4), l.GUIDID)) AS Diff
	, l.GUIDID AS LowerGUID 
	, h.GUIDID AS HigherGUID
	, l.InsWhen AS LowerTimeInserted
	, h.InsWhen AS HigherTimeInserted
FROM SequentialGUIDs AS l
	JOIN SequentialGUIDs AS h
		ON l.RowID + 1 = h.RowID
WHERE convert(int, convert(varbinary(4), h.GUIDID)) - convert(int, convert(varbinary(4), l.GUIDID)) <> 1

select * from RandomGUIDs